#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SPLITFACTOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SPLITFACTOR_HPP_INCLUDED

#include <boost/simd/constant/include/constants/splitfactor.hpp>

#endif
